@@ -35,7 +35,7 @@ class Client:
         self.path = os.path.abspath(os.path.dirname(__file__))
         self.debug = config.get("debug", False)
         self.follow_profiles_list = config.get("follow_profiles", None)
-        self.chromedriver_path = config.get(chromedriver_path, "/usr/lib/chromium-browser/chromedriver")
+        self.chromedriver_path = config.get("chromedriver_path", "/usr/lib/chromium-browser/chromedriver")
         self.likes_max = config.get("likes", 15)
         self.watch_stories_minutes = config.get("watch_stories_minutes", 5)
         self.follows_max = config.get("follow", 0)
